..
  Licensed under the Apache License, Version 2.0 (the "License"); you may
  not use this file except in compliance with the License. You may obtain
  a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
  License for the specific language governing permissions and limitations
  under the License.

.. _ref-index:

====================
Builtin Policy Types
====================

The senlin service is released with some builtin policy types that target some
most common use cases. You can develop and deploy your own policy types by
following the instructions in the
:doc:`developer guide <../../../developer/index>`.

The following is a list of builtin policy types that are shipped with the
service package.

.. toctree::
   :maxdepth: 1

   affinity
   deletion
   load_balancing
   scaling
   region_placement
   zone_placement
